<?php
/*
	Plugin Name: email validator
	Plugin URI: http://www.saalwaechter.org/
	Description: This plugin detects temporary email addresses
	Author: Mathias Saalwächter
	Version: 1.1
 */

// Check if we are running PHP5 or above, otherwise die with an error message.
function ev_activation_check()
{
	if (version_compare(PHP_VERSION, '5.0.0', '<'))
	{
		deactivate_plugins(basename(__FILE__));
		wp_die("Sorry, but you can't run this plugin, it requires PHP 5 or higher.");
	}
}

register_activation_hook(__FILE__, 'ev_activation_check');

add_action('admin_menu', 'ev_menu');

function ev_menu() {
	add_options_page('email validator Options', 'Block temporary and not connectable email addresses', 'manage_options', 'ev-admin-menu', 'ev_options');
	add_action( 'admin_init', 'register_ev_settings' );
}

function plugin_section_text() {

}

function plugin_setting_string() {
	$options = get_option('ev_plugin_options');
}

function register_ev_settings() {
        register_setting( 'ev_plugin_options', 'ev_plugin_options');
        add_settings_section('plugin_main', 'Main Settings', 'plugin_section_text', 'plugin');
}

function domainAvailable($strDomain) { 
    $rCurlHandle = curl_init($strDomain); 

	curl_setopt($rCurlHandle, CURLOPT_CONNECTTIMEOUT, 10); 
    curl_setopt($rCurlHandle, CURLOPT_HEADER, TRUE); 
    curl_setopt($rCurlHandle, CURLOPT_NOBODY, TRUE); 
    curl_setopt($rCurlHandle, CURLOPT_RETURNTRANSFER, TRUE); 

    $strResponse = curl_exec($rCurlHandle); 

    curl_close($rCurlHandle); 

    if (!$strResponse) { 
		return FALSE; 
    } 

    return TRUE; 
} 

 // Add a settings link in the plugin listing
	add_filter('plugin_action_links', 'plugin_action_links', 10, 2);

function ev_options() { 
?>
<div>
	<h2>email validator</h2>
	<p>This plugin detects one-time email addresses (disposable email, trashmail, mailinator) and helps to keep your userbase and comments clean.</p>
	<p>This plugin prevent visitors from registering with temporary email addresses like the ones provided by mailinator (also known as throw-away email, one-time email, disposable email). It protects the most important asset, the registered user base, by preventing contamination by fake accounts. This plugin working principle is similar to spam blacklists. It hooks in the wordpress function is_email() so it will extend the known email validation of wordpress to detect the email addresses. The plugin itself does not contain a list of domains to block. Instead of local maintenance the plugin uses the service of http://www.saalwaechter.org. This is a very accurate free service.</p>
	<h3>Connectivity</h3>
<?php 
	if(domainAvailable("https://www.saalwaechter.org/email-validator")) {
?><p style="width: 388px; padding: .5em; background-color: #4AB915; color: #fff; font-weight:bold;">All servers are available.</p>
	<p>email validator is working correctly. The server is available.</p>
	<table style="width: 400px;">
		<thead>
			<tr>
				<th style="text-align: left">Server</th>
				<th style="text-align: left">Status</th>
			</tr>
		</thead>
		<tbody>
			<tr>
				<td>5.35.244.224</td>
				<td style="padding: 0 .5em; font-weight:bold; color: #fff; background-color: #4AB915">Server available</td>
			</tr>
		</tbody>
	</table>
<?php
	} else {
?><p style="width: 388px; padding: .5em; background-color: #e21414; color: #fff; font-weight:bold;">Not all servers are available.</p>
	<p>email validator doesn't working correctly. The server is not available.</p>
	<table style="width: 400px;">
		<thead>
			<tr>
				<th style="text-align: left">Server</th>
				<th style="text-align: left">Status</th>
			</tr>
		</thead>
		<tbody>
			<tr>
				<td>5.35.244.224</td>
				<td style="padding: 0 .5em; font-weight:bold; color: #fff; background-color: #e21414">Server is not available</td>
			</tr>
		</tbody>
	</table>
<?php
	}
?>
</div>
<?php
	}

function plugin_action_links($links, $file) {
	static $this_plugin;
	if (!$this_plugin) {
		$this_plugin = plugin_basename(__FILE__);
	}

	if ($file == $this_plugin) {
		$settings_link = '<a href="options-general.php?page=ev-admin-menu">' . __('Settings') . '</a>';
		array_unshift($links, $settings_link);
	}

	return $links;
}

// Hooks, Functions
add_filter ( 'is_email', 'ev_check' );

function ev_check ($email){

	$url = "https://www.saalwaechter.org/email-validator.json?email_address=".$email."&encoding=false";
	$contents = file_get_contents($url); 
	$contents = utf8_encode($contents); 
	$results = json_decode($contents); 

	if ($results[0]->status == "OK" && $results[0]->results[0]->domain_exists == true && $results[0]->results[0]->domain_receives_emails == true && $results[0]->results[0]->domain_is_blacklisted == false) {
		return true;
	} else { 
		return false;
	}
}
?>